==> stitcher-0.3.1.tgz: package/lib/main.js <==
var fs = require('fs');
var path = require('path');
var optimist = require('optimist');
var connect = require('connect');
var index = require('./index');
var css = require('./css');
var script = require('./script');
var util = require('./util');
var wrench = require('wrench')

var argv = optimist.usage(['  usage: stitcher COMMAND',
 '	server',
 '	build',
 '	buildAll'].join("\n")).alias('p', 'port').argv;
 
function help() {
    optimist.showHelp();
    return process.exit();
};
 
function Package(options){
	this.options = {
		build: './build/',
		css: './css/',
		src: './src/',
		tmpl: './tmpl/',
		images: './images/',
		index: './index.html',
		ouputJsFolder:'/js/',
		ouputCssFolder:'/css/',
		ouputTmplFolder:'/template/',
		ouputImagesFolder:'/images/',
		configFile: './project.json',
		port: process.env.PORT || argv.port || 8124
	};
	for(var p in options){
		this.options[p] = options[p];
	}
	options = this.readConfig();
	for(var p in options){
		this.options[p] = options[p];
	}
}

Package.prototype = {
	server:function (){
		var app, indexServer, scriptServer,cssServer;
		scriptServer = new script.Package(this.options);
		cssServer = new css.Package(this.options);
		indexServer = new index.Package(this.options);
		app = connect.createServer();
		app.use(connect.favicon());
		var staticFiles =  connect.static(this.options.images,{maxAge: 0});
		var cssStaticFiles =  connect.static(this.options.css,{maxAge: 0});
		app.use('/images/',staticFiles);	
		app.use('/index.html', indexServer.createServer.bind(indexServer));
		app.use(this.options.ouputJsFolder, scriptServer.createServer.bind(scriptServer));
		app.use(this.options.ouputCssFolder, cssServer.createServer.bind(cssServer));
		app.use(this.options.ouputTmplFolder, scriptServer.createServer.bind(scriptServer));
		app.use('/require.js',scriptServer.requireJs.bind(scriptServer))
		app.listen(this.options.port);
	},
	build:function (){
		wrench.rmdirSyncRecursive(this.options.build);
		util.mkdirs(this.options.build,function (){			
			var app, indexServer, scriptServer,cssServer;
			scriptServer = new script.Package(this.options);
			cssServer = new css.Package(this.options);
			indexServer = new index.Package(this.options);
			indexServer.build();
			cssServer.build();
			scriptServer.build();
			
			wrench.copyDirSyncRecursive(this.options.images,path.join('./',this.options.build,'./images'));
		}.bind(this));
	},
	buildAll:function (){
		wrench.rmdirSyncRecursive(this.options.build);
		util.mkdirs(this.options.build,function (){	
			var app, indexServer, scriptServer,cssServer;
			scriptServer = new script.Package(this.options);
			cssServer = new css.Package(this.options);
			indexServer = new index.Package(this.options);
			indexServer.buildAll();
			cssServer.buildAll();
			scriptServer.buildAll();
			wrench.copyDirSyncRecursive(this.options.images,path.join('./',this.options.build,'./images'));
		}.bind(this));
	},
	exec: function(command) {
		if (command == null) command = argv._[0];
		if (!this[command]) return help();
		this[command]();
		var str = {'server':'Starting server on: ' + this.options.port,
					'build':'building',
					'buildAll':'building'
					}[command];
		console.log(str);		
    },
	readConfig : function(file) {
		if (file == null) file = this.options.configFile;
		if (!(file && path.existsSync(file))) return {};
		return JSON.parse(fs.readFileSync(file, 'utf-8'));
    }
};

Package.exec = function(command, options) {
	return (new Package(options)).exec(command);
};
exports.Package = Package;
exports.exec = Package.exec;

==> stitcher-0.3.4.tgz: package/lib/main.js <==
var fs = require('fs');
var path = require('path');
var optimist = require('optimist');
var connect = require('connect');
var index = require('./index');
var css = require('./css');
var script = require('./script');
var util = require('./util');
var wrench = require('wrench')

var argv = optimist.usage(['  usage: stitcher COMMAND',
 '	server',
 '	build',
 '	buildAll'].join("\n")).alias('p', 'port').argv;
 
function help() {
    optimist.showHelp();
    return process.exit();
};
 
function Package(options){
	this.options = {
		build: './build/',
		css: './css/',
		src: './src/',
		tmpl: './tmpl/',
		images: './images/',
		index: './index.html',
		ouputJsFolder:'/js/',
		ouputCssFolder:'/css/',
		ouputTmplFolder:'/template/',
		ouputImagesFolder:'/images/',
		configFile: './project.json',
		port: process.env.PORT || argv.port || 8124
	};
	for(var p in options){
		this.options[p] = options[p];
	}
	options = this.readConfig();
	for(var p in options){
		this.options[p] = options[p];
	}
}

Package.prototype = {
	server:function (){
		var app, indexServer, scriptServer,cssServer;
		scriptServer = new script.Package(this.options);
		cssServer = new css.Package(this.options);
		indexServer = new index.Package(this.options);
		app = connect.createServer();
		app.use(connect.favicon());
		var staticFiles =  connect.static(this.options.images,{maxAge: 0});
		var cssStaticFiles =  connect.static(this.options.css,{maxAge: 0});
		app.use('/images/',staticFiles);	
		app.use('/index.html', indexServer.createServer.bind(indexServer));
		app.use(this.options.ouputJsFolder, scriptServer.createServer.bind(scriptServer));
		app.use(this.options.ouputCssFolder, cssServer.createServer.bind(cssServer));
		app.use(this.options.ouputTmplFolder, scriptServer.createServer.bind(scriptServer));
		app.use('/require.js',scriptServer.requireJs.bind(scriptServer));
		app.use('/', indexServer.createServer.bind(indexServer));
		app.listen(this.options.port);
	},
	build:function (){
		wrench.rmdirSyncRecursive(this.options.build);
		util.mkdirs(this.options.build,function (){			
			var app, indexServer, scriptServer,cssServer;
			scriptServer = new script.Package(this.options);
			cssServer = new css.Package(this.options);
			indexServer = new index.Package(this.options);
			indexServer.build();
			cssServer.build();
			scriptServer.build();
			
			wrench.copyDirSyncRecursive(this.options.images,path.join('./',this.options.build,'./images'));
		}.bind(this));
	},
	buildAll:function (){
		wrench.rmdirSyncRecursive(this.options.build);
		util.mkdirs(this.options.build,function (){	
			var app, indexServer, scriptServer,cssServer;
			scriptServer = new script.Package(this.options);
			cssServer = new css.Package(this.options);
			indexServer = new index.Package(this.options);
			indexServer.buildAll();
			cssServer.buildAll();
			scriptServer.buildAll();
			wrench.copyDirSyncRecursive(this.options.images,path.join('./',this.options.build,'./images'));
		}.bind(this));
	},
	exec: function(command) {
		if (command == null) command = argv._[0];
		if (!this[command]) return help();
		this[command]();
		var str = {'server':'Starting server on: ' + this.options.port,
					'build':'building',
					'buildAll':'building'
					}[command];
		console.log(str);		
    },
	readConfig : function(file) {
		if (file == null) file = this.options.configFile;
		if (!(file && path.existsSync(file))) return {};
		return JSON.parse(fs.readFileSync(file, 'utf-8'));
    }
};

Package.exec = function(command, options) {
	return (new Package(options)).exec(command);
};
exports.Package = Package;
exports.exec = Package.exec;
